@@ -1,29 +1,9 @@
-# VERSION
-from . import mimodd_base
-version = mimodd_base.Version((0, 4, 5))
-
-# new in 0,4,5:
-# fixed generation of @PG line in new SAM/BAM header by fq2sam
-# new in 0,4,4:
-# adapted to new fastqReader object
-# new in 0,4,3:
-# object-based version handling
-# new in 0,4,2:
-# delegated argparsing to function clparse
-# new in 0,4,0:
-# updated doc strings
-# new in 0,3,0:
-# correct handling of read tags
-# and of PG header line
-# new in 0,1,0:
-# added class UnAlignedReader to simplify read initialization
-
 import sys
 import os
 import gzip  # to open compressed fastq files
 
 from collections import namedtuple
-from . import pysamtools, samheader, pysam
+from . import mimodd_base, pysamtools, samheader, pysam
 
 # TO DO:
 # customize ReHeaderSpecs to do default initialization and argument checking
@@ -62,7 +42,7 @@ class ReHeader (object):
         self.sq_mapping = sq_mapping
         self.original = samheader.Header(ori_header_lines)
         self.new = samheader.Header(ori_header_lines)
-
+        
         if any(
             param == '-' for param in (t_default, rg_specs.template,
                                        sq_specs.template, co_specs.template)):
@@ -216,7 +196,11 @@ def fq2sam (filelist1, filelist2, outputname=None, inputcomp=True, outputcomp=Tr
         new_header = samheader.Header()
 
     # add yourself to the @PG lines
-    new_header['PG'].append({'ID':'MiModD', 'PN':'mimodd convert', 'CL': ' '.join(sys.argv), 'VN': str(version)})
+    new_header['PG'].append(
+                    {'ID':'MiModD', 'PN':'mimodd convert',
+                     'CL': ' '.join(sys.argv),
+                     'VN': str(mimodd_base.__version__)
+                    })
     # if no read group was specified, use default
     if not new_header['RG']:
         new_header['RG']=[{'ID':'000'}]
@@ -313,7 +297,7 @@ def sam2bam (infile, ofile=None, iformat='sam', oformat='bam', reheader = None):
         if errors:
             print(errors)
 
-def convert (input1, input2 = None, iformat = 'fastq', oformat = 'sam',
+def convert (input1, input2 = None, iformat = 'bam', oformat = 'sam',
               outputname = None, header = None):
     supported = {'fastq':('sam', 'bam'),
                  'gz':('sam', 'bam'),
@@ -428,9 +412,13 @@ def clparse_reheader(**args):
     # - template file names following an initial 'ignore' value
     specs = {}
     for argname in ('rg', 'sq', 'co'):
+        if not args.get(argname):
+            if args.get('template'):
+                args[argname] = ['replace']
+            else:
+                args[argname] = ['ignore']
         mode = template = None
         id_mapping = {}
-        
         if args[argname][0] not in ('ignore', 'replace', 'update'):
             raise ValueError ('Unknown --sq option value. Expected one of: ignore, replace, update')
         if args[argname][0] != 'ignore':
