@@ -1,7 +1,3 @@
-# VERSION
-from . import mimodd_base
-version = mimodd_base.Version((0, 0, 2))
-
 import sys
 
 from . import samheader, pyvcf, pysamtools, covtools
