@@ -1,7 +1,3 @@
-# VERSION
-from . import mimodd_base
-version = mimodd_base.Version((0, 0, 1))
-
 from itertools import chain
 
 def fisher_hyper (a,b,c,d):
