@@ -6,23 +6,6 @@ When run from the command line, parses the command line
 arguments, calls sam_header and either prints the returned header object or
 writes it to the specified output file."""
 
-# VERSION
-from . import mimodd_base
-version = mimodd_base.Version((0, 5, 0))
-
-# new in 0,5,0:
-# moved the Header class from pysamtools to this module
-# added uniquify_sm() to Header
-# bug fix version 0,4,2
-# to do: radically restructure sam_header signature
-# new in 0,4,1:
-# delegated __main__ functionality to functions clparse and run_as_main
-# new in 0,4,0:
-# updated all doc strings
-# sam_header now returns pysamtools.Header instance
-# new in 0,3,0:
-# output only minimal sequence dictionary
-
 import sys
 import os
 import datetime
