@@ -8,53 +8,6 @@ and to merge the results into a single output file organized in several read
 groups. This function is used by the GALAXY interface of MiModD.
 """
 
-# VERSION
-from . import mimodd_base
-version = mimodd_base.Version((0, 9, 4))
-
-# bug fix version 0,9,3
-# bug fix version 0,9,2
-# new in 0,9,1:
-# improved handling of header information (taken from input file or custom_header information)
-# new in 0,9,0:
-# improved handling of read pair overlaps (allowed fraction of overlap is now adjustable)
-# made command line more similar to that of SNAP
-# added multi-threading to snap_index
-# bug fix version 0,8,5
-# new in 0,8,4:
-# complete handling of SIGTERM
-# new in 0,8,3:
-# (incomplete) handling of SIGTERM
-# new in 0,8,2:
-# object-based version handling
-# --version switch on command line routes to stdout
-# new in 0,8,1:
-# snap_batch handles indexing intelligently now,
-# creating repeatedly used index directories only once
-# new in 0,8,0:
-# snap_call can deal with reference genome or pre-existing index
-# introduced optional permanent idx_out directory
-# made snap index a separate function
-# new in 0,7,2:
-# introduced verbose and quiet arguments in snap_call
-# started implementing piping
-# new in 0,7,1:
-# made all parameter names in snap_call match those of SNAP
-# new in 0,7,0:
-# introduced snap_batch (replacing the previous 'batch' mode inside snap_call)
-# made make_snap_argdictlist accept any iterator instead of a batch file name
-# added doc strings
-# new in 0,6,4:
-# takes tempfile_dir and threads number from config.py
-# new in 0,6,3:
-# improved read tag and header reconstitution
-# bug fix version (0,6,2)
-# bug fix version (0,6,1)
-# new in version (0,5,4):
-# paired-read filtering to remove small template fragments
-# new in version (0,5,0):
-# introduced batch mode for running several snap_caller jobs specified in a file
-
 import sys, os
 import signal
 import shutil
@@ -63,7 +16,7 @@ import argparse     # to parse arguments out of sys.argv
 import gzip   # to handle compressed data
 from collections import Counter
 
-from . import config, pysamtools, samheader, pysam, tmpfiles
+from . import config, mimodd_base, pysamtools, samheader, pysam, tmpfiles
 from .decox import parachute, FuncInfo
 from .fasta import FastaReader
 
