@@ -1,61 +1,9 @@
 """Provides a functional approach to variant calling.
 
 The current version supports variant calling using samtools mpileup and
-bcftools through the core function varcall.
-The snpeff function provides a Python interface for the Java-based SnpEff
-application to add gene annotation info to vcf files. 
+bcftools through the single function varcall.
 """
 
-# VERSION
-from . import mimodd_base
-version = mimodd_base.Version((0, 8, 5))
-
-# bug fix version 0,8,5
-# bug fix version 0,8,4
-# bug fix version 0,8,3
-# new in 0, 8, 2:
-# made coverage output optional
-# new in 0, 8, 1:
-# improved use of temporary index files
-# new in 0, 8, 0:
-# strict sample grouping (by read group id) fully functional
-# switched to tempfile module for creating temporary output files
-# new in 0, 7, 0:
-# proper multi-processing in SNP calling without invoking the system shell
-# proper SIGTERM handling under all conditions
-# proper separation of stderr messages by subprocesses
-# respects config.multithreading_level
-# new in 0,6,5:
-# introduced SIGTERM handling
-# new in 0,6,4:
-# started incorporating strict sample grouping
-# still need to test new functionality
-# improved error handling
-# new in 0,6,3:
-# ensure unique names for temporary files
-# new in 0,6,2:
-# optional variant or fixed sites output to stdout
-# new in 0,6,1:
-# added verbose and quiet arguments to varcall and snpeff
-# proper splitting of varcall output to stdout and stderr
-# new in 0,6,0:
-# merged in snpeff
-# new in 0,5,0:
-# added clparse
-# added doc strings
-# new in 0,4,2:
-# sets temporary file directory from config.py
-# some bug fixes
-# new in (0,4,1):
-# added the sites parameter, still needs to be tested
-# new in (0,4,0):
-# comparison of input bam file header SQ dictionaries; need to be identical to start SNP calling
-# sample-specific AD information gets added to vcf output during postprocessing
-# new in (0,3,1):
-# made columns in coverage file dependent on sample number instead of file number
-# new in (0,3,0):
-# fixed a bug in the coverage file generator, which prevented it from writing positions with zero coverage
-
 import sys
 import os
 import io
